@@ -1,5 +1,5 @@
 /* digest.c --- Generate a CRAM-MD5 hex encoded HMAC-MD5 response string.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU SASL Library; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307 USA
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -48,8 +48,8 @@
  *
  */
 
-#if CRAM_MD5_DIGEST_LEN != 2* GC_MD5_LEN
-# error MD5 length mismatch
+#if CRAM_MD5_DIGEST_LEN != 2*GC_MD5_DIGEST_SIZE
+#error MD5 length mismatch
 #endif
 
 #define HEXCHAR(c) ((c & 0x0F) > 9 ? 'a' + (c & 0x0F) - 10 : '0' + (c & 0x0F))
@@ -60,14 +60,14 @@ cram_md5_digest (const char *challenge,
 		 const char *secret,
 		 size_t secretlen, char response[CRAM_MD5_DIGEST_LEN])
 {
-  char hash[GC_MD5_LEN];
+  char hash[GC_MD5_DIGEST_SIZE];
   size_t i;
 
   gc_hmac_md5 (secret, secretlen ? secretlen : strlen (secret),
 	       challenge, challengelen ? challengelen : strlen (challenge),
 	       hash);
 
-  for (i = 0; i < GC_MD5_LEN; i++)
+  for (i = 0; i < GC_MD5_DIGEST_SIZE; i++)
     {
       *response++ = HEXCHAR (hash[i] >> 4);
       *response++ = HEXCHAR (hash[i]);
