@@ -1,5 +1,5 @@
 /* parser.c --- SCRAM parser.
- * Copyright (C) 2009, 2010  Simon Josefsson
+ * Copyright (C) 2009-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 /* Get prototypes. */
@@ -101,10 +101,10 @@ scram_parse_client_first (const char *str, size_t len,
       cf->cbname = malloc (p - str + 1);
       if (!cf->cbname)
 	return -1;
-      memcpy (cf->cbname, str, p - str + 1);
-      cf->cbname[p- str] = '\0';
-      str += (p - str);
+      memcpy (cf->cbname, str, p - str);
+      cf->cbname[p - str] = '\0';
       len -= (p - str);
+      str += (p - str);
     }
 
   if (len == 0 || *str != ',')
