@@ -1,5 +1,5 @@
 /* server.c --- SASL CRAM-MD5 server side functions.
- * Copyright (C) 2009, 2010  Simon Josefsson
+ * Copyright (C) 2009-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 /* Get specification. */
@@ -50,38 +50,44 @@
 
 struct scram_server_state
 {
+  int plus;
   int step;
-  char *gs2header; /* copy of client first gs2-header */
-  char *cfmb_str; /* copy of client first message bare */
-  char *sf_str; /* copy of server first message */
+  char *cbind;
+  char *gs2header;		/* copy of client first gs2-header */
+  char *cfmb_str;		/* copy of client first message bare */
+  char *sf_str;			/* copy of server first message */
   char *snonce;
   char *clientproof;
   char *storedkey;
   char *serverkey;
   char *authmessage;
+  char *cbtlsunique;
+  size_t cbtlsuniquelen;
   struct scram_client_first cf;
   struct scram_server_first sf;
   struct scram_client_final cl;
   struct scram_server_final sl;
 };
 
-int
-_gsasl_scram_sha1_server_start (Gsasl_session * sctx, void **mech_data)
+static int
+scram_start (Gsasl_session * sctx, void **mech_data, int plus)
 {
   struct scram_server_state *state;
   char buf[MAX (SNONCE_ENTROPY_BYTES, DEFAULT_SALT_BYTES)];
+  const char *p;
   int rc;
 
   state = (struct scram_server_state *) calloc (sizeof (*state), 1);
   if (state == NULL)
     return GSASL_MALLOC_ERROR;
 
+  state->plus = plus;
+
   rc = gsasl_nonce (buf, SNONCE_ENTROPY_BYTES);
   if (rc != GSASL_OK)
     goto end;
 
-  rc = gsasl_base64_to (buf, SNONCE_ENTROPY_BYTES,
-			&state->snonce, NULL);
+  rc = gsasl_base64_to (buf, SNONCE_ENTROPY_BYTES, &state->snonce, NULL);
   if (rc != GSASL_OK)
     goto end;
 
@@ -89,22 +95,47 @@ _gsasl_scram_sha1_server_start (Gsasl_session * sctx, void **mech_data)
   if (rc != GSASL_OK)
     goto end;
 
-  rc = gsasl_base64_to (buf, DEFAULT_SALT_BYTES,
-			&state->sf.salt, NULL);
+  rc = gsasl_base64_to (buf, DEFAULT_SALT_BYTES, &state->sf.salt, NULL);
   if (rc != GSASL_OK)
     goto end;
 
+  p = gsasl_property_get (sctx, GSASL_CB_TLS_UNIQUE);
+  if (plus && !p)
+    {
+      rc = GSASL_NO_CB_TLS_UNIQUE;
+      goto end;
+    }
+  if (p)
+    {
+      rc = gsasl_base64_from (p, strlen (p), &state->cbtlsunique,
+			      &state->cbtlsuniquelen);
+      if (rc != GSASL_OK)
+	goto end;
+    }
+
   *mech_data = state;
 
   return GSASL_OK;
 
- end:
+end:
   free (state->sf.salt);
   free (state->snonce);
   free (state);
   return rc;
 }
 
+int
+_gsasl_scram_sha1_server_start (Gsasl_session * sctx, void **mech_data)
+{
+  return scram_start (sctx, mech_data, 0);
+}
+
+int
+_gsasl_scram_sha1_plus_server_start (Gsasl_session * sctx, void **mech_data)
+{
+  return scram_start (sctx, mech_data, 1);
+}
+
 int
 _gsasl_scram_sha1_server_step (Gsasl_session * sctx,
 			       void *mech_data,
@@ -129,8 +160,14 @@ _gsasl_scram_sha1_server_step (Gsasl_session * sctx,
 	if (scram_parse_client_first (input, input_len, &state->cf) < 0)
 	  return GSASL_MECHANISM_PARSE_ERROR;
 
-	/* We don't support channel bindings. */
-	if (state->cf.cbflag != 'n' && state->cf.cbflag != 'y')
+	/* In PLUS server mode, we require use of channel bindings. */
+	if (state->plus && state->cf.cbflag != 'p')
+	  return GSASL_AUTHENTICATION_ERROR;
+
+	/* In non-PLUS mode, but where have channel bindings data (and
+	   thus advertised PLUS) we reject a client 'y' cbflag. */
+	if (!state->plus
+	    && state->cbtlsuniquelen > 0 && state->cf.cbflag == 'y')
 	  return GSASL_AUTHENTICATION_ERROR;
 
 	/* Check that username doesn't fail SASLprep. */
@@ -226,21 +263,39 @@ _gsasl_scram_sha1_server_step (Gsasl_session * sctx,
 	  return GSASL_AUTHENTICATION_ERROR;
 
 	/* Base64 decode the c= field and check that it matches
-	   client-first. */
+	   client-first.  Also check channel binding data. */
 	{
 	  size_t len;
-	  char *cbind;
 
 	  rc = gsasl_base64_from (state->cl.cbind, strlen (state->cl.cbind),
-				  &cbind, &len);
+				  &state->cbind, &len);
 	  if (rc != 0)
 	    return rc;
 
-	  if (len != strlen (state->gs2header))
-	    return GSASL_AUTHENTICATION_ERROR;
+	  if (state->cf.cbflag == 'p')
+	    {
+	      if (len < strlen (state->gs2header))
+		return GSASL_AUTHENTICATION_ERROR;
 
-	  if (memcmp (cbind, state->gs2header, len) != 0)
-	    return GSASL_AUTHENTICATION_ERROR;
+	      if (memcmp (state->cbind, state->gs2header,
+			  strlen (state->gs2header)) != 0)
+		return GSASL_AUTHENTICATION_ERROR;
+
+	      if (len - strlen (state->gs2header) != state->cbtlsuniquelen)
+		return GSASL_AUTHENTICATION_ERROR;
+
+	      if (memcmp (state->cbind + strlen (state->gs2header),
+			  state->cbtlsunique, state->cbtlsuniquelen) != 0)
+		return GSASL_AUTHENTICATION_ERROR;
+	    }
+	  else
+	    {
+	      if (len != strlen (state->gs2header))
+		return GSASL_AUTHENTICATION_ERROR;
+
+	      if (memcmp (state->cbind, state->gs2header, len) != 0)
+		return GSASL_AUTHENTICATION_ERROR;
+	    }
 	}
 
 	/* Base64 decode client proof and check that length matches
@@ -328,8 +383,8 @@ _gsasl_scram_sha1_server_step (Gsasl_session * sctx,
 
 	    n = asprintf (&state->authmessage, "%s,%.*s,%.*s",
 			  state->cfmb_str,
-			  strlen (state->sf_str), state->sf_str,
-			  len, input);
+			  (int) strlen (state->sf_str), state->sf_str,
+			  (int) len, input);
 	    if (n <= 0 || !state->authmessage)
 	      return GSASL_MALLOC_ERROR;
 	  }
@@ -406,6 +461,8 @@ _gsasl_scram_sha1_server_finish (Gsasl_session * sctx, void *mech_data)
   if (!state)
     return;
 
+  free (state->cbind);
+  free (state->gs2header);
   free (state->cfmb_str);
   free (state->sf_str);
   free (state->snonce);
@@ -413,6 +470,7 @@ _gsasl_scram_sha1_server_finish (Gsasl_session * sctx, void *mech_data)
   free (state->storedkey);
   free (state->serverkey);
   free (state->authmessage);
+  free (state->cbtlsunique);
   scram_free_client_first (&state->cf);
   scram_free_server_first (&state->sf);
   scram_free_client_final (&state->cl);
