@@ -1,5 +1,5 @@
 /* done.c --- Exit point for libgsasl.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
+ * Copyright (C) 2002-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -42,8 +42,7 @@ gsasl_done (Gsasl * ctx)
     if (ctx->client_mechs[i].client.done)
       ctx->client_mechs[i].client.done (ctx);
 
-  if (ctx->client_mechs)
-    free (ctx->client_mechs);
+  free (ctx->client_mechs);
 #endif
 
 #ifdef USE_SERVER
@@ -51,8 +50,7 @@ gsasl_done (Gsasl * ctx)
     if (ctx->server_mechs[i].server.done)
       ctx->server_mechs[i].server.done (ctx);
 
-  if (ctx->server_mechs)
-    free (ctx->server_mechs);
+  free (ctx->server_mechs);
 #endif
 
   free (ctx);
